@@ -119,7 +119,8 @@ class TaskProcessor:
         if provider in self.registry.task_executors:
             return self.registry.task_executors[provider]
         elif provider in self.registry.deprecated_task_executors:
-            log.warning(f'{provider} is a deprecated executor and will be removed in the future')
+            log.warning(
+                f'{provider} is a deprecated executor and will be removed in the future')
             return self.registry.deprecated_task_executors[provider]
         else:
             raise ValueError(
